@@ -4,7 +4,6 @@ from botocore.client import ClientError
 from django_q.brokers import Broker
 from django_q.conf import Conf
 
-
 QUEUE_DOES_NOT_EXIST = "AWS.SimpleQueueService.NonExistentQueue"
 
 
@@ -77,7 +76,7 @@ class Sqs(Broker):
             # exist try to create it.
             return self.sqs.get_queue_by_name(QueueName=self.list_key)
         except ClientError as exp:
-            if not exp.response["Error"]["Code"] == QUEUE_DOES_NOT_EXIST:
+            if exp.response["Error"]["Code"] != QUEUE_DOES_NOT_EXIST:
                 raise exp
 
         return self.sqs.create_queue(QueueName=self.list_key)
