@@ -595,7 +595,7 @@ def scheduler(broker: Broker = None):
                 if s.hook:
                     q_options["hook"] = s.hook
                 # set up the next run time
-                if not s.schedule_type == s.ONCE:
+                if s.schedule_type != s.ONCE:
                     next_run = arrow.get(s.next_run)
                     while True:
                         if s.schedule_type == s.MINUTES:
@@ -633,7 +633,12 @@ def scheduler(broker: Broker = None):
                     )
                     s.repeats += -1
                 # send it to the cluster
-                q_options["broker"] = broker
+                scheduled_broker = broker
+                try:
+                    scheduled_broker = get_broker(q_options["broker_name"])
+                except: # invalid broker_name or non existing broker with broker_name
+                    pass
+                q_options["broker"] = scheduled_broker
                 q_options["group"] = q_options.get("group", s.name or s.id)
                 kwargs["q_options"] = q_options
                 s.task = django_q.tasks.async_task(s.func, *args, **kwargs)
@@ -717,8 +722,9 @@ def set_cpu_affinity(n: int, process_ids: list, actual: bool = not Conf.TESTING)
 
 
 def rss_check():
-    if Conf.MAX_RSS and resource:
-        return resource.getrusage(resource.RUSAGE_SELF).ru_maxrss >= Conf.MAX_RSS
-    elif Conf.MAX_RSS and psutil:
-        return psutil.Process().memory_info().rss >= Conf.MAX_RSS * 1024
+    if Conf.MAX_RSS:
+        if resource:
+            return resource.getrusage(resource.RUSAGE_SELF).ru_maxrss >= Conf.MAX_RSS
+        elif psutil:
+            return psutil.Process().memory_info().rss >= Conf.MAX_RSS * 1024
     return False
